import { initReport, initIssues, initCounters } from './issues/initializers.js';
import { LineRewriter } from './util/log.js';
import { relativePosix } from './util/path.js';
export class IssueCollector {
    report;
    issues;
    counters;
    lineRewriter;
    pluginEntryFile;
    referencedFiles;
    cwd;
    constructor({ cwd, report }) {
        this.lineRewriter = new LineRewriter();
        this.cwd = cwd;
        this.report = report ?? initReport();
        this.issues = initIssues();
        this.counters = initCounters();
        this.pluginEntryFile = new Set();
        this.referencedFiles = new Set();
    }
    setTotalFileCount(count) {
        this.counters.total = count;
    }
    addFilesIssues(filePaths) {
        filePaths.forEach(filePath => {
            if (!this.referencedFiles.has(filePath)) {
                this.issues.files.add(filePath);
                this.counters.files++;
                this.counters.processed++;
            }
        });
    }
    addIssue(issue) {
        const key = relativePosix(this.cwd, issue.filePath);
        this.issues[issue.type][key] = this.issues[issue.type][key] ?? {};
        if (!this.issues[issue.type][key][issue.symbol]) {
            this.issues[issue.type][key][issue.symbol] = issue;
            this.counters[issue.type]++;
        }
    }
    setReport(report) {
        this.report = report;
    }
    getIssues() {
        return {
            report: this.report,
            issues: this.issues,
            counters: this.counters,
        };
    }
}
