import ts from 'typescript';
import { SourceFileManager } from './typescript/SourceFileManager.js';
import type { ExportItem, ExportItemMember } from './types/ast.js';
import type { SyncCompilers, AsyncCompilers } from './types/compilers.js';
import type { Report } from './types/issues.js';
type ProjectPrincipalOptions = {
    compilerOptions: ts.CompilerOptions;
    cwd: string;
    report: Report;
    compilers: [SyncCompilers, AsyncCompilers];
};
export declare class ProjectPrincipal {
    entryPaths: Set<string>;
    projectPaths: Set<string>;
    skipExportsAnalysis: Set<string>;
    cwd: string;
    compilerOptions: ts.CompilerOptions;
    isReportTypes: boolean;
    extensions: Set<string>;
    syncCompilers: SyncCompilers;
    asyncCompilers: AsyncCompilers;
    backend: {
        fileManager: SourceFileManager;
        compilerHost: ts.CompilerHost;
        languageServiceHost: ts.LanguageServiceHost;
        lsFindReferences: ts.LanguageService['findReferences'];
        program?: ts.Program;
    };
    constructor({ compilerOptions, cwd, report, compilers }: ProjectPrincipalOptions);
    private createProgram;
    private hasAcceptedExtension;
    addEntryPath(filePath: string): void;
    addEntryPaths(filePaths: Set<string> | string[]): void;
    addProjectPath(filePath: string): void;
    skipExportsAnalysisFor(filePaths: string[]): void;
    runAsyncCompilers(): Promise<void>;
    getUsedResolvedFiles(): string[];
    private getProgramSourceFiles;
    getUnreferencedFiles(): string[];
    analyzeSourceFile(filePath: string): {
        internalImports: import("./types/ast.js").Imports;
        unresolvedImports: Set<string>;
        externalImports: Set<string>;
        exports: import("./types/ast.js").ExportItems;
        duplicateExports: string[][];
    };
    private resolveModule;
    hasExternalReferences(filePath: string, exportedItem: ExportItem): boolean;
    findUnusedMembers(filePath: string, members: ExportItemMember[]): string[];
    private findReferences;
    isPublicExport(exportedItem: ExportItem): ts.JSDocPublicTag | undefined;
}
export {};
