import path from 'node:path';
import parseArgs from 'minimist';
import { isInNodeModules } from '../../path.js';
import { tryResolve } from '../../require.js';
const tryResolveFilePath = (cwd, specifier, fallback) => {
    if (specifier) {
        const filePath = path.join(cwd, specifier);
        if (!isInNodeModules(filePath)) {
            const resolvedFilePath = tryResolve(filePath);
            if (resolvedFilePath)
                return [resolvedFilePath];
        }
        return fallback ? [fallback] : [];
    }
    return [];
};
export const tryResolveFilePaths = (cwd, specifiers) => specifiers.flatMap(specifier => tryResolveFilePath(cwd, specifier, specifier));
export const resolve = (binary, args, { cwd }) => {
    const parsed = parseArgs(args, { string: ['r'], alias: { require: ['r', 'loader', 'experimental-loader'] } });
    return [...tryResolveFilePath(cwd, parsed._[0]), ...tryResolveFilePaths(cwd, [parsed.require].flat())];
};
